<?php
/**
 * The loop that displays posts.
 */
global $sonar_options;
$sonar_options = get_option('sonar_theme_options');
?>

<?php /* Display navigation to next/previous pages when applicable */ ?>
<?php if ( $wp_query->max_num_pages > 1 ) : ?>
	<div id="nav-above" class="navigation">
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'sonar' ) ); ?></div>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'sonar' ) ); ?></div>
	</div><!-- #nav-above -->
<?php endif; ?>

<?php /* If there are no posts to display, such as an empty archive page */ ?>
<?php if ( ! have_posts() ) : ?>
	<article id="post-0" class="post error404 not-found">
		<h1 class="entry-title"><?php _e( 'Not Found', 'sonar' ); ?></h1>
		<div class="entry-content">
			<p><?php _e( 'Apologies, but no results were found for the requested archive. Perhaps searching will help find a related post.', 'sonar' ); ?></p>
			<?php get_search_form(); ?>
		</div><!-- .entry-content -->
	</article><!-- #post-0 -->
<?php endif; ?>

<?php
	/* Start the Loop.
	 */ ?>
<?php while ( have_posts() ) : the_post(); ?>

<?php /* How to display posts of the Gallery format. The gallery category is the old way. */ ?>

	<?php if ( ( function_exists( 'get_post_format' ) && 'gallery' == get_post_format( $post->ID ) ) || in_category( _x( 'gallery', 'gallery category slug', 'sonar' ) ) ) : ?>
		<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
			<h2 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'sonar' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h2>

			<div class="entry-meta">
				<?php sonar_posted_on(); ?>
			</div><!-- .entry-meta -->

			<div class="entry-content">
<?php if ( post_password_required() ) : ?>
				<?php the_content(); ?>
<?php else : ?>
				<?php
					$images = get_children( array( 'post_parent' => $post->ID, 'post_type' => 'attachment', 'post_mime_type' => 'image', 'orderby' => 'menu_order', 'order' => 'ASC', 'numberposts' => 999 ) );
					if ( $images ) :
						$total_images = count( $images );
						$image = array_shift( $images );
						$image_img_tag = wp_get_attachment_image( $image->ID, 'thumbnail' );
				?>
						<div class="gallery-thumb">
							<a class="size-thumbnail" href="<?php the_permalink(); ?>"><?php echo $image_img_tag; ?></a>
						</div><!-- .gallery-thumb -->
						<p><em><?php printf( _n( 'This gallery contains <a %1$s>%2$s photo</a>.', 'This gallery contains <a %1$s>%2$s photos</a>.', $total_images, 'sonar' ),
								'href="' . get_permalink() . '" title="' . sprintf( esc_attr__( 'Permalink to %s', 'sonar' ), the_title_attribute( 'echo=0' ) ) . '" rel="bookmark"',
								number_format_i18n( $total_images )
							); ?></em></p>
				<?php endif; ?>
						<?php the_excerpt(); ?>
<?php endif; ?>
			</div><!-- .entry-content -->

			<div class="entry-utility">
			<?php if ( function_exists( 'get_post_format' ) && 'gallery' == get_post_format( $post->ID ) ) : ?>
				<a href="<?php echo get_post_format_link( 'gallery' ); ?>" title="<?php esc_attr_e( 'View Galleries', 'sonar' ); ?>"><?php _e( 'More Galleries', 'sonar' ); ?></a>
				<span class="meta-sep">|</span>
			<?php elseif ( in_category( _x( 'gallery', 'gallery category slug', 'sonar' ) ) ) : ?>
				<a href="<?php echo get_term_link( _x( 'gallery', 'gallery category slug', 'sonar' ), 'category' ); ?>" title="<?php esc_attr_e( 'View posts in the Gallery category', 'sonar' ); ?>"><?php _e( 'More Galleries', 'sonar' ); ?></a>
				<span class="meta-sep">|</span>
			<?php endif; ?>
				<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'sonar' ), __( '1 Comment', 'sonar' ), __( '% Comments', 'sonar' ) ); ?></span>
				<?php edit_post_link( __( 'Edit', 'sonar' ), '<span class="meta-sep">|</span> <span class="edit-link">', '</span>' ); ?>
			</div><!-- .entry-utility -->
		</article><!-- #post-## -->

<?php // How to display posts of the Status format. ?>
	<?php elseif ( ( function_exists( 'get_post_format' ) && 'status' == get_post_format( $post->ID ) ) || in_category( _x( 'status', 'status category slug', 'sonar' ) ) ) : ?>
			<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
				<div class="entry-status-format"><?php _e( 'Status', 'sonar' ); ?></div>
		<?php if ( is_archive() || is_search() ) : // Display excerpts for archives and search. ?>
			<div class="entry-summary">
				<?php the_excerpt(); ?>
			</div><!-- .entry-summary -->
		<?php else : ?>
			<div class="entry-content">
				<?php if ( comments_open() ) : ?>
				<?php if ( isset ($sonar_options['sonar_remove_reply_bubble']) &&  ($sonar_options['sonar_remove_reply_bubble']!="") ) {echo' ';}
				else { ?>
				<div class="comments-link-top">
					<?php comments_popup_link( __( '<span class="leave-reply">Reply</span>', 'sonar' ), __( '1', 'sonar' ), __( '%', 'sonar' ) ); ?>
				</div>
			<?php } endif; ?>
				<div class="avatar"><?php echo get_avatar( $post->post_author, apply_filters( 'sonar_status_avatar', '65' ) ); ?></div>
				<?php the_content( __( '<span class="read-more">Read more <span class="meta-nav">&raquo;</span>', 'sonar' ) ); ?>
			</div><!-- .entry-content -->
		<?php endif; ?>

			<div class="entry-utility">
				<?php sonar_posted_on(); ?>
				<span class="meta-sep">|</span>
				<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'sonar' ), __( '1 Comment', 'sonar' ), __( '% Comments', 'sonar' ) ); ?></span>
				<?php edit_post_link( __( 'Edit', 'sonar' ), '<span class="meta-sep"></span> <span class="edit-link">', '</span>' ); ?>
			</div><!-- .entry-utility -->
		</article><!-- #post-## -->
		
<?php /* How to display posts of the Aside format. The asides category is the old way. */ ?>

	<?php elseif ( ( function_exists( 'get_post_format' ) && 'aside' == get_post_format( $post->ID ) ) || in_category( _x( 'asides', 'asides category slug', 'sonar' ) )  ) : ?>
		<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>

		<?php if ( is_archive() || is_search() ) : // Display excerpts for archives and search. ?>
			<div class="entry-summary">
				<?php the_excerpt(); ?>
			</div><!-- .entry-summary -->
		<?php else : ?>
			<div class="entry-content">
				<?php if ( comments_open() ) : ?>
				<?php if ( isset ($sonar_options['sonar_remove_reply_bubble']) &&  ($sonar_options['sonar_remove_reply_bubble']!="") ) {echo' ';}
				else { ?>
				<div class="comments-link-top">
					<?php comments_popup_link( __( '<span class="leave-reply">Reply</span>', 'sonar' ), __( '1', 'sonar' ), __( '%', 'sonar' ) ); ?>
				</div>
				<?php } endif; ?>
				<?php if ( isset ($sonar_options['sonar_remove_post_calendar']) && ($sonar_options['sonar_remove_post_calendar']!="") )
						{echo' ';}
				else { ?>
					<div class="calendar">
						<span class="month"><?php the_time("M", get_option('date_format')); ?></span>
						<span class="day"><?php the_time("d", get_option('date_format')); ?></span>
					</div><!-- calendar --><?php
				} ?>
				<?php the_content( __( '<span class="read-more">Read More <span class="meta-nav">&raquo;</span>', 'sonar' ) ); ?>
			</div><!-- .entry-content -->
		<?php endif; ?>

			<div class="entry-utility">
				<?php sonar_posted_on(); ?>
				<span class="meta-sep">|</span>
				<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'sonar' ), __( '1 Comment', 'sonar' ), __( '% Comments', 'sonar' ) ); ?></span>
				<?php edit_post_link( __( 'Edit', 'sonar' ), '<span class="meta-sep"></span> <span class="edit-link">', '</span>' ); ?>
			</div><!-- .entry-utility -->
		</article><!-- #post-## -->

<?php /* How to display all other posts. */ ?>

	<?php else : ?>
		<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
			<?php if ( comments_open() ) : ?>
			<?php if ( isset ($sonar_options['sonar_remove_reply_bubble']) &&  ($sonar_options['sonar_remove_reply_bubble']!="") ) {echo' ';}
			else { ?>
			<div class="comments-link-top">
				<?php comments_popup_link( __( '<span class="leave-reply">Reply</span>', 'sonar' ), __( '1', 'sonar' ), __( '%', 'sonar' ) ); ?>
			</div>
			<?php } endif; ?>
			<?php if ( isset ($sonar_options['sonar_remove_post_calendar']) &&  ($sonar_options['sonar_remove_post_calendar']!="") )
				{echo' ';}
			else { ?>
				<div class="calendar">
					<span class="month"><?php the_time("M", get_option('date_format')); ?></span>
					<span class="day"><?php the_time("d", get_option('date_format')); ?></span>
				</div><!-- calendar --><?php
			} ?>
			<h2 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'sonar' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h2>

			<div class="entry-meta">
				<?php sonar_posted_on(); ?>
			</div><!-- .entry-meta -->

	<?php if ( is_archive() || is_search() ) : // Only display excerpts for archives and search. ?>
			<div class="entry-summary">
				<?php the_excerpt(); ?>
			</div><!-- .entry-summary -->
	<?php else : ?>
			<div class="entry-content">
				<?php the_content( __( '<span class="read-more">Read More <span class="meta-nav">&raquo;</span>', 'sonar' ) ); ?>
				<?php wp_link_pages( array( 'before' => '<div class="page-link">' . __( 'Pages:', 'sonar' ), 'after' => '</div>' ) ); ?>
			</div><!-- .entry-content -->
	<?php endif; ?>

			<div class="entry-utility">
				<?php if ( count( get_the_category() ) ) : ?>
					<span class="cat-links">
						<?php printf( __( '<span class="%1$s">Posted in</span> %2$s', 'sonar' ), 'entry-utility-prep entry-utility-prep-cat-links', get_the_category_list( ', ' ) ); ?>
					</span>
					<span class="meta-sep">|</span>
				<?php endif; ?>
				<?php
					$tags_list = get_the_tag_list( '', ', ' );
					if ( $tags_list ):
				?>
					<span class="tag-links">
						<?php printf( __( '<span class="%1$s">Tagged</span> %2$s', 'sonar' ), 'entry-utility-prep entry-utility-prep-tag-links', $tags_list ); ?>
					</span>
					<span class="meta-sep">|</span>
				<?php endif; ?>
				<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'sonar' ), __( '1 Comment', 'sonar' ), __( '% Comments', 'sonar' ) ); ?></span>
				<?php edit_post_link( __( 'Edit', 'sonar' ), '<span class="meta-sep"></span> <span class="edit-link">', '</span>' ); ?>
			</div><!-- .entry-utility -->
		</article><!-- #post-## -->

		<?php comments_template( '', true ); ?>

	<?php endif; // This was the if statement that broke the loop into three parts based on categories. ?>

<?php endwhile; ?>

<?php /* Display navigation when applicable */ ?>
<?php if (  $wp_query->max_num_pages > 1 ) : ?>
				<?php /* add page navigation to indexes */ ?>
				<?php if (function_exists("sonar_pagination")) {
						sonar_pagination($wp_query->max_num_pages);
				} 
endif; ?>